@@ -19,7 +19,6 @@
 #ifndef CREATOR
 
 #include "level.h"
-
 #include "points.h"
 #include "archi.h"
 #include "configuration.h"
@@ -30,6 +29,7 @@
 #include "decl.h"
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #define TOWERWID 16
 
@@ -242,10 +242,10 @@ void lev_findmissions() {
     delete n;
   }
 
-#if (SYSTEM == SYS_WINDOWS)
+#ifdef WIN32
   {
     char n[100];
-    GetCurrentDirectory(100, n);
+    getcwd(n, 100);
     sprintf(pathname, "%s\\", n);
   }
 #else
@@ -269,7 +269,7 @@ void lev_findmissions() {
   free(eps);
   eps = NULL;
 
-#if (SYSTEM != SYS_WINDOWS)
+#ifndef WIN32
 
   snprintf(pathname, 100, "%s/.toppler/", getenv("HOME"));
   n = alpha_scandir(pathname, &eps, missionfiles);
