@@ -28,19 +28,16 @@
 #include <stdlib.h>
 #include <time.h>
 #include <string.h>
-
-#if ENABLE_NLS == 1
-#include <libintl.h>
-#endif
-
+#include <unistd.h>
 
 #include <stdexcept>
 
-#if (SYSTEM != SYS_WINDOWS)
-#include <unistd.h>
+#if ENABLE_NLS == 1
+#include <libintl.h>
+#include <sys/types.h>
+#include <dirent.h>
 #endif
 
-
 static void printhelp(void) {
   printf(_("\n\tOptions:\n\n  -f\tEnable fullscreen mode\n  -s\tSilence, disable all sound\n  -dX\tSet debug level to X  (default: %i)\n"), config.debug_level());
 }
@@ -97,18 +94,16 @@ int main(int argc, char *argv[]) {
   setlocale(LC_MESSAGES, "");
   setlocale(LC_CTYPE, "");
 
-//  bindtextdomain("toppler", LOCALEDIR"/locale");
-  bindtextdomain("toppler", "po");
+  DIR *dir = opendir("locale");
+  bindtextdomain("toppler", dir == NULL ? LOCALEDIR : "locale");
+  closedir(dir);
   textdomain("toppler");
 #endif
 
-#ifdef VERSION
   printf(_("Nebulous version %s"), VERSION);
-#else
-  printf(_("Nebulous"));
-#endif
   printf("\n");
 
+  printf("hsc init\n");
   hsc_init();
 
   if (parse_arguments(argc, argv)) {
